@@ -1,18 +1,18 @@
 #!/usr/bin/env python3
 import sys
-import time
+from loadconf import Config
 from pathlib import Path
-from .config import UserSettings
 from .options import get_opts
 from .prompts import zathura_prompt
 from .utils import (
-    write_pid_file,
     get_next_or_prev_file,
     NoFileOrDirectory,
 )
 from .zathura import Zathura
 from .zsocket import send_to_socket
 
+# from .config import UserSettings
+
 
 __license__ = "GPL-v3.0"
 __program__ = "znp"
@@ -25,6 +25,7 @@ def open_next_or_prev(
     next_file=False,
     prev_file=False,
     prompt_cmd=None,
+    page_number=-1,
 ):
     """
     Open file in zathura optionally open the next file in
@@ -55,23 +56,19 @@ def open_next_or_prev(
             pass
     # Try searching for the given file manually
     # If found open it and exit
-    if z.zathura_search(z.pids, search_file=file_path):
+    if z.zathura_search(z.pids, search_file=file_path, page_number=page_number):
         z.open(file_path=next_or_prev_file, pid=z.search_pid)
-        # z.remove_tmp_files()
         return 0
     # No prompt_cmd given, exit
     if not prompt_cmd:
-        # z.remove_tmp_files()
         return 1
     # Prompt user for their desired instance
     choice = zathura_prompt(pid_dict=z.pid_dict, prompt_cmd=prompt_cmd)
     # No selection made, exit
     if not choice:
-        # z.remove_tmp_files()
         return 1
     # Try opening the next file and exit
     z.open(file_path=next_or_prev_file, pid=choice)
-    # z.remove_tmp_files()
     return 0
 
 
@@ -126,22 +123,23 @@ def main():
     Main function for znp
     """
     args = get_opts()
+    user = Config(__program__)
     user_files = {
         "conf_file": f"{__program__}.conf",
     }
+    read_files = ["conf_file"]
+    user.define_files(user_files=user_files)
+    user.create_files(create_files=read_files)
     default_settings = {
         "prompt_cmd": "fzf",
         "prompt_args": "",
     }
-    read_files = ["conf_file"]
-    user = UserSettings(
-        program=__program__,
-        cmd_line_args=args,
-        user_files=user_files,
-        default_settings=default_settings,
+    user.define_settings(settings=default_settings)
+    user_settings = ["prompt_cmd", "prompt_args"]
+    user.read_conf(
+        user_settings=user_settings,
         read_files=read_files,
     )
-    args = user.cmd_args
     # Connect client to server_address to send args.file and args.pid
     # to the calling znp server
     if args.client is not None:
@@ -150,6 +148,7 @@ def main():
             parent_pid=args.source,
             file_path=args.file,
             server_address=args.client,
+            page_number=args.page,
         )
     # User is opening next or prev file
     if args.next or args.prev:
@@ -157,16 +156,21 @@ def main():
             file_path=args.file,
             next_file=args.next,
             prev_file=args.prev,
-            prompt_cmd=user.prompt_cmd,
+            prompt_cmd=user.settings["prompt_cmd"],
+            page_number=args.page,
         )
     # User just wants a the pid of a specific instance
     if args.query:
-        return z.query(search_file=args.file)
+        return z.query(search_file=args.file, page_number=args.page)
+    if args.execute is not None:
+        if z.query(search_file=args.file, page_number=args.page, print_result=False):
+            return 1
+        return z.execute(pid=z.search_pid, command=args.execute)
     # User wants to open the given file in an optionally given zathura instance
     return open_given_file(
         file_path=args.file,
-        prompt_cmd=user.prompt_cmd,
-        prompt_args=user.prompt_args,
+        prompt_cmd=user.settings["prompt_cmd"],
+        prompt_args=user.settings["prompt_args"],
         pid=args.pid,
     )
 
