@@ -1,6 +1,5 @@
 #!/usr/bin/env python3
 import os
-import sys
 import psutil
 import dbus
 import subprocess
@@ -117,11 +116,13 @@ class Zathura:
         if not pid:
             zathuraPopen = subprocess.Popen(["zathura", file_path])
             return 0
+        # Close current file so progress is saved
         # Open the given file
         zathuraName = "org.pwmt.zathura.PID-" + str(pid)
         zathuraObject = dbus.SessionBus().get_object(zathuraName, "/org/pwmt/zathura")
         zathuraDBus = dbus.Interface(zathuraObject, "org.pwmt.zathura")
-        zathuraDBus.OpenDocument(file_path, "", 0)
+        zathuraDBus.ExecuteCommand("close")
+        zathuraDBus.ExecuteCommand(f'open "{file_path}"')
         return 0
 
     def pid_search(self, name="zathura"):
@@ -143,7 +144,7 @@ class Zathura:
         self.pid_count = len(pids)
         return None
 
-    def query(self, search_file):
+    def query(self, search_file, page_number, print_result=True):
         """
         Query zathura instances for the instance with search_file open.
         If found prints the pid, else nothing and exits with status 1.
@@ -151,15 +152,19 @@ class Zathura:
         if self.pid_count == 0:
             return 1
         elif self.pid_count == 1:
-            print(self.pids[0])
+            if print_result:
+                print(self.pids[0])
             return 0
-        elif self.zathura_search(self.pids, search_file=search_file):
-            print(self.search_pid)
+        elif self.zathura_search(
+            self.pids, search_file=search_file, page_number=page_number
+        ):
+            if print_result:
+                print(self.search_pid)
             return 0
 
         return 1
 
-    def zathura_search(self, pids, search_file=None, prog="znp"):
+    def zathura_search(self, pids, search_file=None, page_number=-1, prog="znp"):
         """
         Search for an instance of zathura using bad means.
         This creates a dictionary of zathura instances if multiple exist:
@@ -181,14 +186,15 @@ class Zathura:
             expected_messages=pid_count,
         )
         # Give server some time to start
-        time.sleep(0.05)
+        time.sleep(0.005)
         # Get pid of current script in case client fails it will kill
         # this script so user is not left with a hanging process/socket
         ppid = os.getpid()
         # Run clients to find current files in each pid
         for pid in pids:
             self.execute(
-                pid, f"exec znp -P {pid} -s {ppid} -c {server_address} '$FILE'"
+                pid,
+                f"exec znp -P {pid} -s {ppid} -c {server_address} '$FILE' -g '$PAGE'",
             )
         # Wait for server to get all client messages
         while server.recieved < pid_count:
@@ -201,9 +207,13 @@ class Zathura:
             return True
         # Search the pid_dict for the desired file
         for key, value in server.pid_dict.items():
-            if value[0] == search_file:
-                # Search_file found set search_pid and return True
-                self.search_pid = key
-                return True
+            if value[2] == search_file:
+                # Search_file found, set search_pid and return True
+                if page_number > -1 and page_number == int(value[1]):
+                    self.search_pid = key
+                    return True
+                elif page_number == -1:
+                    self.search_pid = key
+                    return True
         # Desired instance wasn't found return False
         return False
